@@ -12,7 +12,7 @@ from typing import (
     runtime_checkable,
 )
 
-from injection._core.common.asynchronous import Caller, run_sync
+from injection._core.common.asynchronous import Caller
 from injection._core.scope import Scope, get_active_scopes, get_scope
 from injection.exceptions import InjectionError
 
@@ -107,25 +107,31 @@ class ScopedInjectable[R, T](Injectable[T], ABC):
         raise NotImplementedError
 
     async def aget_instance(self) -> T:
-        scope = get_scope(self.scope_name)
+        scope = self.get_scope()
 
         with suppress(KeyError):
             return scope.cache[self]
 
         instance = await self.abuild(scope)
-        scope.cache[self] = instance
+        self.set_instance(instance, scope)
         return instance
 
     def get_instance(self) -> T:
-        scope = get_scope(self.scope_name)
+        scope = self.get_scope()
 
         with suppress(KeyError):
             return scope.cache[self]
 
         instance = self.build(scope)
-        scope.cache[self] = instance
+        self.set_instance(instance, scope)
         return instance
 
+    def get_scope(self) -> Scope:
+        return get_scope(self.scope_name)
+
+    def set_instance(self, instance: T, scope: Scope) -> None:
+        scope.cache[self] = instance
+
     def unlock(self) -> None:
         if self.is_locked:
             raise RuntimeError(f"To unlock, close the `{self.scope_name}` scope.")
@@ -138,8 +144,8 @@ class AsyncCMScopedInjectable[T](ScopedInjectable[AsyncContextManager[T], T]):
         cm = await self.factory.acall()
         return await scope.aenter(cm)
 
-    def build(self, scope: Scope) -> T:
-        return run_sync(self.abuild(scope))
+    def build(self, scope: Scope) -> NoReturn:
+        raise RuntimeError("Can't use async context manager synchronously.")
 
 
 class CMScopedInjectable[T](ScopedInjectable[ContextManager[T], T]):
